[![Stars](https://img.shields.io/github/stars/zhangqf-lab/SPACE?logo=GitHub&color=yellow)](https://github.com/zhangqf-lab/SPACE) [![PyPI](https://img.shields.io/pypi/v/space-srt.svg)](https://pypi.org/project/space-srt)

# Spatial transcriptomics data analysis via interaction-aware cell embedding reveals cell communities with characteristic cell-cell interactions
SPACE (**SP**atial transcriptomics **A**nalysis via **C**ell **E**mbedding)

## Installation  	
#### install from PyPI

```shell
pip install space-srt
```

#### install from GitHub

install the latest develop version

```shell
git clone https://github.com/zhangqf-lab/SPACE.git
cd SPACE
python setup.py install
```

SPACE is implemented in [Pytorch](https://pytorch.org/) framework.  
SPACE can be run on CPU devices, and running SPACE on GPU devices if available is recommended.   

### Tutorial
A brief tutorial can be found [here](https://tutorial-space.readthedocs.io/en/latest/).（Still in progress）

### Citation
If you use SPACE in your research, please cite our paper:

Li, Y., Zhang J., Gao, X., and Zhang, Q.C. Tissue module discovery in single-cell resolution spatial transcriptomics data via cell- cell interaction-aware cell embedding. Cell Systems 2024 (Accepted)
